%if 0%{?fedora} < 30 || 0%{?rhel}
%global build_for_python2 1
%endif

%if 0%{?rhel}
%global py3dir py%{python3_other_pkgversion}dir
%endif

%global srcname metar
%global summary Coded METAR and SPECI weather reports parser for Python

Name: python-%{srcname}
Version: 1.6.0
Release: 2%{?dist}
Summary: %{summary}

License: MIT
Group: Development/Languages
URL: https://github.com/python-metar/python-metar
# note that development was moved to a new github account
# the old account was: http://github.com/tomp/python-metar
# see also this discussion on the 2 project names:
# https://github.com/python-metar/python-metar/issues/58
Source: https://files.pythonhosted.org/packages/source/m/%{srcname}/%{srcname}-%{version}.tar.gz

# fix a mistake in importing Datatypes and in handling nsd_cccc.txt
# reported upstream as issue #60:
# https://github.com/python-metar/python-metar/issues/60
# and a pull-request suggested for this patch:
# https://github.com/python-metar/python-metar/pull/61
Patch1: metar-station.patch

BuildArch: noarch

%if 0%{?build_for_python2}
BuildRequires: python2-devel python2-nose
%endif
%if 0%{?fedora}
BuildRequires: python3-devel python3-nose
%endif
%if 0%{?rhel}
# python3-nose seems not available for epel7
# python36-devel replaced python3-devel on rhel
BuildRequires: python%{python3_other_pkgversion}-devel
BuildRequires: python%{python3_other_pkgversion}-nose
%endif

%global _description \
Python-metar is a python package for interpreting METAR and SPECI coded \
weather reports.  METAR (Meteorological Aerodrome Report) and SPECI (Specials) \
are reports containing airport weather information encoded in ASCII \
following standards set by WMO (World Meteorological Organization) \
and ICAO (International Civil Aviation Organization).

%description %_description

%if 0%{?build_for_python2}

%package -n python2-%{srcname}
Summary: %{summary}
%if 0%{?fedora}
%{?python_provide:%python_provide python2-%{srcname}}
%endif

%description -n python2-%{srcname} %_description

%endif

%package -n python3-%{srcname}
Summary: %{summary}
%if 0%{?fedora}
%{?python_provide:%python_provide python3-%{srcname}}
%endif

%description -n python3-%{srcname} %_description

#%%package -n python%%{python3_pkgversion}-%%{srcname}
#Summary: %%{summary}

#%%package -n python%%{python3_other_pkgversion}-%%{srcname}
#Summary: %%{summary}

#%%description -n python%%{python3_pkgversion}-%%{srcname} %%_description

#%%description -n python%%{python3_other_pkgversion}-%%{srcname} %%_description

%prep
%autosetup -n %{srcname}-%{version} -p1

# remove shebang lines from library files
# to prevent non-executable-script and wrong-script-interpreter warnings 
sed -i -e '/^#!\//, 1d' metar/*.py

%if 0%{?rhel}
# setup build dir for python3
#rm -rf %{py3dir}
#mkdir %{py3dir}
#ls -1 | grep -v %{py3dir} | xargs -I file cp -a file %{py3dir}
# ls -l %{py3dir}
%endif

%build

# this does not work at all, even though it is
# advocated in https://fedoraproject.org/wiki/PackagingDrafts:Python3EPEL
#%py2_build
#%py3_build
#%py3_other_build

%if 0%{?build_for_python2}
%py2_build
%endif
%if 0%{?fedora}
%py3_build
%endif
%if 0%{?rhel}
#pushd %{py3dir}
# this does not work for me
#%%{__python3_other} setup.py build
python%{python3_other_pkgversion} setup.py build
#popd
%endif

%install

#%py2_install
#%py3_install
#%py3_other_install

%if 0%{?build_for_python2}
%py2_install
%endif
%if 0%{?fedora}
%py3_install
%endif
%if 0%{?rhel}
#pushd %{py3dir}

# this does not work!
#%%global PY3INSTALLPATH %%{buildroot}/usr/lib/python%%{python3_other_pkgversion}/site-packages
%global PY3INSTALLPATH %{buildroot}/usr/lib/python3.6/site-packages
mkdir -p %PY3INSTALLPATH
PYTHONPATH=%PY3INSTALLPATH \
/usr/bin/python%{python3_other_pkgversion} setup.py  install \
 --prefix %{buildroot}/usr/ --skip-build

rm %{buildroot}/usr/lib/python3.6/site-packages/site.py
rm %{buildroot}/usr/lib/python3.6/site-packages/__pycache__/site.cpython*.pyc
rmdir %{buildroot}/usr/lib/python3.6/site-packages/__pycache__

#popd
%endif

# sample file is not present in version 1.6.0 (by mistake?)
# remove executable permissions from sample.py to
# prevent dependencies being pulled in from this file
#chmod 644 sample.py

# test/all_tests.py is not present in version 1.5.0 (by mistake?)
%check

# the travis testing is done like this:
# nosetests --with-coverage --cover-package=metar --verbose

%if 0%{?build_for_python2}
%{__python2} setup.py test
%if 0%{?fedora}
nosetests-2 --verbose
%endif
%if 0%{?rhel}
# in rhel the nosetests-2 executable has a different name ...
nosetests --verbose
# or nosetests-2,7 --verbose
%endif
%endif

%if 0%{?fedora}
%{__python3} setup.py test
nosetests-3 --verbose
%endif
%if 0%{?rhel}
/usr/bin/python%{python3_other_pkgversion} setup.py test
nosetests-3.6 --verbose
%endif

%if 0%{?build_for_python2}
%files -n python2-%{srcname}
%doc LICENSE README.md PKG-INFO
# sample.py
%{python2_sitelib}/*
%endif

%files -n python3-%{srcname}
%doc LICENSE README.md PKG-INFO
# sample.py

%if 0%{?fedora}
%{python3_sitelib}/*
%endif

%if 0%{?rhel}
/usr/lib/python3.6/site-packages/*.pth
%dir /usr/lib/python3.6/site-packages/metar*.egg
%dir /usr/lib/python3.6/site-packages/metar*.egg/EGG-INFO
%dir /usr/lib/python3.6/site-packages/metar*.egg/metar
/usr/lib/python3.6/site-packages/metar*.egg/metar/*.py
/usr/lib/python3.6/site-packages/metar*.egg/metar/*.txt
/usr/lib/python3.6/site-packages/metar*.egg/metar/__pycache__/*.pyc

# this does NOT work!!!
#/usr/lib/python%%{python3_other_pkgversion}/site-packages/metar*.egg/EGG-INFO/*
/usr/lib/python3.6/site-packages/metar*.egg/EGG-INFO/*

# these files seem to be created by the python3.6 install step
# actually I have no clue whatsoever if I should include them or not
# for now, since they seem a generic artefact of installing a
# simple python3 module I'll assume I should not package them
# and I'll delete them in the install step above
#/usr/lib/python3.6/site-packages/site.py
#/usr/lib/python3.6/site-packages/__pycache__/site.cpython*.pyc
%endif

%changelog
* Sun Sep 23 2018 Jos de Kloe <josdekloe@gmail.com> 1.6.0-2
- allow python2 in rhel builds as well

* Thu Sep 20 2018 Jos de Kloe <josdekloe@gmail.com> 1.6.0-1
- new upstream version and disable python2 sub-package for f30+

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 1.5.0-5
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Jos de Kloe <josdekloe@gmail.com> 1.5.0-3
- undo spec file name change since this seems not allowed

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Jul 01 2017 Jos de Kloe <josdekloe@gmail.com> 1.5.0-1
- new upstream version and adapt to generate python2 and python3 versions

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Oct 08 2015 Jos de Kloe <josdekloe@gmail.com> 1.4.0-1
- Update to new upstream version and simplified spec file
- Add check section and run provided tests

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 1.3.0-7
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.3.0-4
- Rebuild for Python 2.6

* Thu Apr 24 2008 Matthias Saou <http://freshrpms.net/> 1.3.0-3
- Include everything under sitelib, to include egg files if present (F-9+).

* Tue Mar 27 2007 Matthias Saou <http://freshrpms.net/> 1.3.0-2
- Include nobang patch.

* Fri Feb  9 2007 Matthias Saou <http://freshrpms.net/> 1.3.0-1
- Initial RPM release.

